$(document).ready(function () {
    function loadBackground() {
        var randomNum = Math.floor(Math.random() * 7) + 1;
        $('#bg-image').css('background-image', 'url("/res_nethesis/bg/' + randomNum + '.jpeg")');
    }

    function loadApps() {
        var host = document.location.hostname;
        $.getJSON('/res_nethesis/system_apps.php', function (systemApps) {
            var apps = [];
            apps['user'] = [];
            apps['admin'] = [];
            apps['report'] = [];

            $.each(systemApps, function (key, appInfo) {
                var appUrl;

                if (appInfo.url) {
                    // external app
                    appUrl = appInfo.url;
                } else {
                    appUrl = 'https://' + host + ':9090/nethserver#/applications/' + appInfo.id
                }

                if (appInfo.category) {
                    // html for app icon
                    apps[appInfo.category].push('<div class="app col app-' + appInfo.category + '" data-sort="' + appInfo.position + '"><a target="_blank" href="' + appUrl + '"><img src="/res_nethesis/app-icons/' + appInfo.id + '.png" alt="app icon" class="icon"><p class="app-name" data-i18n="' + appInfo.id + '"></p></a></div>');
                }
            });

            for (var category of ['user', 'admin', 'report']) {
                if (apps[category].length > 0) {
                    // html for category
                    $('#' + category + '-apps-container').append('<div class="app-category"><div class="app-category-title" data-i18n="' + category + '-apps"></div><div id="apps-' + category +'" class="category-panel row"></div></div>');
                    $("#apps-" + category).append(apps[category].join(""));
                }

                // sort apps in category
                var sortedCategory = $('.app-' + category).sort(function (a, b) {
                    var contentA = parseInt( $(a).attr('data-sort'));
                    var contentB = parseInt( $(b).attr('data-sort'));
                    return (contentA - contentB);
                });
                $('#apps-' + category).html(sortedCategory);
            }
            // hide loader
            $('#spinner-container').hide();
            loadI18n();
        });
    }

    function loadI18n() {
        var lang = navigator.language.substring(0, 2);
        var i18nMap = [];
        $.getJSON('/res_nethesis/i18n.json', function (data) {
            $.each(data, function (key, val) {
                i18nMap[key] = val;
            });

            $('[data-i18n]').each(function( index ) {
                $( this ).text(i18nMap[lang][$(this).attr('data-i18n')]);
            });

            // placeholder for Google search
            $('#google-input-search').attr("placeholder", "\uf002 " + i18nMap[lang]['google-search']);
        });
    }

    function loadLauncherData() {
        $.getJSON('/res_nethesis/launcher_data.php', function (launcherData) {
            document.title = launcherData.LauncherTitle;
            $('#launcher-title').text(launcherData.LauncherTitle);
            $('#logo').attr('src', '/res_nethesis/' + launcherData.LogoImage);
            $('#logo-href').attr('href', launcherData.LogoHref);
            $('#docs-href').attr('href', launcherData.DocsHref);
        });
    }

    loadBackground();
    loadLauncherData();
    loadApps();
});
