<?php
    header('Content-type: application/json');

    $appIdsWithManifest = '["nethserver-webtop5","nethserver-nextcloud","nethserver-mattermost","nethserver-roundcubemail","nethserver-firewall-base","nethserver-mail","nethserver-nethvoice14","inboundreport","queuereport","nethserver-dante","nethserver-squid","nethserver-samba"]';

    // app categories and positions
    $appCategories = [
        'nethserver-webtop5' => [ 'category' => 'user', 'position' => 10],
        'nethcti' => [ 'category' => 'user', 'position' => 20 ],
        'nethserver-nextcloud' => [ 'category' => 'user', 'position' => 30 ],
        'nethserver-mattermost' => [ 'category' => 'user', 'position' => 40 ],
        'nethserver-roundcubemail' => [ 'category' => 'user', 'position' => 50 ],
        'user-settings-page' => [ 'category' => 'user', 'position' => 90 ],

        'server-manager' => [ 'category' => 'admin', 'position' => 10 ],
        'cockpit-apps' => [ 'category' => 'admin', 'position' => 15 ],
        'nethserver-firewall-base' => [ 'category' => 'admin', 'position' => 20 ],
        'nethserver-mail' => [ 'category' => 'admin', 'position' => 30 ],
        'nethserver-nethvoice14' => [ 'category' => 'admin', 'position' => 40 ],

        'inboundreport' => [ 'category' => 'report', 'position' => 10 ],
        'queuereport' => [ 'category' => 'report', 'position' => 20 ],
        'nethserver-dante' => [ 'category' => 'report', 'position' => 40 ],
        'nethserver-squid' => [ 'category' => 'report', 'position' => 50 ],
        'nethserver-samba' => [ 'category' => 'report', 'position' => 60 ],
    ];

    $systemApps = shell_exec('echo \'{"action":"launcher","appIds":' . $appIdsWithManifest . ',"location":{"hostname":"' . $_SERVER['SERVER_NAME'] . '", "protocol":"https:"}}\' | /usr/bin/sudo /usr/libexec/nethserver/api/system-apps/read');
    $systemAppsJson = json_decode($systemApps, true);

    if (is_null($systemAppsJson)) {
        // invalid json
        echo json_encode([]);
    } else {
        // manually added apps
        array_push($systemAppsJson, [ "id" => "cockpit-apps", "url" => "https://" . $_SERVER['SERVER_NAME'] . ":9090/nethserver#/applications" ]);
        array_push($systemAppsJson, [ "id" => "server-manager", "url" => "https://" . $_SERVER['SERVER_NAME'] . ":9090" ]);

        $nethvoiceInstalled = FALSE;

        // set category and position
        foreach ($systemAppsJson as &$app) {
            if (array_key_exists($app["id"], $appCategories)) {
                $app["category"] = $appCategories[$app["id"]]["category"];
                $app["position"] = $appCategories[$app["id"]]["position"];

                if (strcmp("nethserver-nethvoice14", $app["id"]) == 0) {
                    $nethvoiceInstalled = TRUE;
                }

                if (strcmp("user-settings-page", $app["id"]) == 0) {
                    $alias = $app["url"];
                    $app["url"] = "https://" . $_SERVER['SERVER_NAME'] . $alias;
                }
            }
        }

        if ($nethvoiceInstalled) {
            // add CTI app as well
            array_push($systemAppsJson, [   "id" => "nethcti", 
                                            "url" => "https://" . $_SERVER['SERVER_NAME'] . "/cti",
                                            "category" => $appCategories["nethcti"]["category"],
                                            "position" => $appCategories["nethcti"]["position"] 
                                        ]);
        }
        $systemApps = json_encode($systemAppsJson);
        echo $systemApps;
    }
