<?php

namespace NethServer\Module;

/*
 * Copyright (C) 2014 Nethesis S.r.l.
 *
 * This script is part of NethServer.
 *
 * NethServer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NethServer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NethServer.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Register a license key (LK) for the local machine
 *
 * @author Davide Principi <davide.principi@nethesis.it>
 */
class Register extends \Nethgui\Controller\CompositeController
{
    const NOC_SYSTEM_FAMILY = 'NSERENT0001';

    protected function initializeAttributes(\Nethgui\Module\ModuleAttributesInterface $base)
    {
        return \Nethgui\Module\SimpleModuleAttributesProvider::extendModuleAttributes($base, 'Administration', 0);
    }

    public function initialize()
    {
        $packageManagerModule = new \NethServer\Module\PackageManager('NethesisPackageManager');

        $authModule = new \NethServer\Module\Register\Authenticate();
        $secret = $this->getPlatform()->getDatabase('configuration')->getProp('subscription','Secret');
        if (!$secret) {
            $children[] = new \NethServer\Module\ForceSecret();
        }
        // swap the first child to select the action shown by default.
        if ( ! $this->isNocAuthorized() ) {
            $children[] = $authModule;
            $children[] = $packageManagerModule;
        } else {
            $children[] = $packageManagerModule;
            $children[] = $authModule;
        }

        foreach ($children as $child) {
            $this->addChild($child);
        }

        parent::initialize();
    }

    public function isServerRegistered()
    {
        return (bool) $this
                ->getPlatform()
                ->getDatabase('configuration')
                ->getProp('subscription', 'SystemId');
    }

    public function isNocAuthorized()
    {
        return $this->getPlatform()->getDatabase('SESSION')->getProp('Authenticate', 'NocAuthorized') === TRUE;
    }

    public function isFreeAccess(\Nethgui\Controller\RequestInterface $request)
    {
        $requestPath = implode('/', $request->getPath());
        if ($requestPath === '' || $requestPath === 'Authenticate' || $requestPath == 'ForceSecret') {
            return TRUE;
        }
        return FALSE;
    }

    public function isSoftwareCenterRequest(\Nethgui\Controller\RequestInterface $request)
    {
        return in_array(\Nethgui\array_head($request->getPath()), array('NethesisPackageManager'));
    }

    public function bind(\Nethgui\Controller\RequestInterface $request)
    {
        if ($this->isFreeAccess($request)) {
            parent::bind($request);
        } elseif ($this->isNocAuthorized() ) {
            parent::bind($request);
        } elseif ($this->isSoftwareCenterRequest($request)) {
            if($this->isServerRegistered() && $this->isNocAuthorized()) {
                parent::bind($request);
            }
        } else {
            throw new \Nethgui\Exception\HttpException('Forbidden', 403, 1394472007);
        }
    }

    public function prepareView(\Nethgui\View\ViewInterface $view)
    {
        if (! $this->isServerRegistered()) {
            parent::prepareView($view);
            $view->setTemplate('NethServer\Template\Register\NoConfig');
            return;
        }

        if($this->getRequest()->isMutation() && $this->getRequest()->isValidated() && $this->isFreeAccess($this->getRequest()) && $this->isServerRegistered()) {
            $packageManager = $this->getAction('NethesisPackageManager');
            $fakeRequest = $this->getRequest()->createSecondaryRequest('Modules/Available')->setAttribute('isValidated', TRUE);
            $packageManager->bind($fakeRequest);
            $subview = $view->spawnView($packageManager, TRUE);
            $packageManager->prepareView($subview);
        }
        parent::prepareView($view);
    }

}
