<?php
namespace NethServer\Module\Register;

/*
 * Copyright (C) 2013 Nethesis S.r.l.
 *
 * This script is part of NethServer.
 *
 * NethServer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NethServer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with NethServer.  If not, see <http://www.gnu.org/licenses/>.
 */

use Nethgui\System\PlatformInterface as Validate;

/**
 * Validate and store Register credentials in session
 *
 * @author Davide Principi <davide.principi@nethesis.it>
 * @since 1.0
 */
class Authenticate extends \Nethgui\Controller\AbstractController
{

    private $serverId;
    private $login = FALSE;

    public function initialize()
    {
        $this->serverId = $this
            ->getPlatform()
            ->getDatabase('configuration')
            ->getProp('subscription', 'SystemId');

        parent::initialize();
        $this->declareParameter('Username', Validate::NOTEMPTY,
            array('SESSION', 'Authenticate', 'Username'));
        $this->declareParameter('Password', Validate::NOTEMPTY,
            array('SESSION', 'Authenticate', 'Password'));
    }

    public function validate(\Nethgui\Controller\ValidationReportInterface $report)
    {
        parent::validate($report);
        if ( ! $this->getRequest()->isMutation() || $report->hasValidationErrors()) {
            return;
        }
        $cmd = '/usr/libexec/nethserver/nethesis-authentication '.escapeshellarg($this->parameters['Username'])." ".escapeshellarg($this->parameters['Password']);
        if ($this->getPlatform()->exec($cmd)->getExitCode() != 0) {
             $report->addValidationErrorMessage($this, 'Username', 'Invalid_credentials_label');
        }
    }

    public function process()
    {
        if ($this->getRequest()->isMutation()) {
            $sessionDb = $this->getPlatform()->getDatabase('SESSION');
            $sessionDb->setProp('Authenticate', array('NocAuthorized' => TRUE));
            $this->login = TRUE;
        }
        parent::process();
    }

    public function prepareView(\Nethgui\View\ViewInterface $view)
    {
        parent::prepareView($view);
        $view['StepNumber'] = $this->serverId;
        if($this->login === TRUE && $this->serverId) {
            $view['sendQuery'] = $view->getModuleUrl('../NethesisPackageManager/Modules');
        }
    }

    public function nextPath()
    {
        if ($this->getRequest()->isMutation()) {
            return $this->serverId ? 'NethesisPackageManager' : 'Subscription';
        }
        return parent::nextPath();
    }

}
