#
# Copyright (C) 2017 Nethesis S.r.l.
# http://www.nethesis.it - nethserver@nethesis.it
#
# This script is part of NethServer.
#
# NethServer is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License,
# or any later version.
#
# NethServer is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with NethServer.  If not, see COPYING.
#

package NethServer::NethBackup;

use strict;
use LWP::UserAgent;
use LWP::Protocol::https;
use URI::Escape;
use JSON;
use NethServer::BackupConfig;
use esmith::ConfigDB;

sub set_proxy
{
    my $ua = shift;
    my $cdb = esmith::ConfigDB->open_ro();
    if(!$cdb) {
        return;
    }
    my $proxy_host = $cdb->get_prop('proxy', 'host') || '';
    my $proxy_port = $cdb->get_prop('proxy', 'port') || '3128';
    my $proxy_user = $cdb->get_prop('proxy', 'user') || '';
    my $proxy_pass = $cdb->get_prop('proxy', 'password') || '';

    if ($proxy_host ne '') {
        if ($proxy_user ne '' && $proxy_pass ne ''){
            $ua->proxy(['http', 'https'], "http://$proxy_user:$proxy_pass\@$proxy_host:$proxy_port");
            $ENV{'HTTPS_PROXY'} = "http://$proxy_host:$proxy_port";
            $ENV{'HTTPS_PROXY_USERNAME'} = $proxy_user;
            $ENV{'HTTPS_PROXY_PASSWORD'} = $proxy_pass;
        } else {
            $ua->proxy(['http', 'https'], "http://$proxy_host:$proxy_port");
        }
    }
}

sub backup_list
{

    my ($key, $secret) = @_;

    my $userAgent = LWP::UserAgent->new('agent' => 'NethBackup');
    set_proxy($userAgent);
    $userAgent->credentials("backupd.nethesis.it:443", "auth_server", $key, $secret);
    $userAgent->default_header('NethBackup-Action' => 'backup-list');
    $userAgent->default_header('NethBackup-Parameters' => 'LK='.  uri_escape($key));

    my $response = $userAgent->post('https://backupd.nethesis.it/backup');
    my $rescon = $response->content;

    chomp($rescon);
    return map { [split(/;/, $_, 2)] } split(/\|/, $rescon);

}


sub get_backup
{
    my ($key, $secret, $bakfile, $fpath) = @_;

    my $userAgent = LWP::UserAgent->new('agent' => 'NethBackup');
    set_proxy($userAgent);
    $userAgent->credentials("backupd.nethesis.it:443", "auth_server", $key, $secret);
    $userAgent->default_header('NethBackup-Action' => 'backup-get');
    $userAgent->default_header('NethBackup-Parameters' =>  "LK=$key&bakfile=$bakfile");

    my $response = $userAgent->post('https://backupd.nethesis.it/backup');
    my $rescon = $response->content;

    if (!$rescon || !$response->is_success) {
        return 0;
    }
    chomp($rescon);
    my $tmp = umask 037;
    open(my $out, '>:raw', $fpath) or die "Unable to open: $!";
    print $out $rescon ;
    close($out);
    umask $tmp;
    return 1;
}

sub send_bck
{
    my ($key, $secret, $filename, $usefname, $desc, $retry) = @_;
    my $buff = undef;

    $retry = 0 if (!$retry);

    $filename =~ /^.*\/(.*)$/; # cutting path
    my $fname = $1;

    open my $fh, '<', $filename or die "error opening $filename: $!";
    my $value = do { local $/; <$fh> };

    my $userAgent = LWP::UserAgent->new('agent' => 'NethBackup');
    set_proxy($userAgent);
    $userAgent->credentials("backupd.nethesis.it:443", "auth_server", $key, $secret);
    $userAgent->default_header('NethBackup-Action' => 'backup-send');
    $userAgent->default_header('NethBackup-Parameters' => 'LK='.  uri_escape($key). ($usefname ? "&fname=". uri_escape($fname) : ''). ($desc ? "&desc=". uri_escape($desc) : ''));

    my $response = $userAgent->post('https://backupd.nethesis.it/backup', Content_Type => 'multipart/form-data', Content => $value);
    my $rescon = $response->content;

    chomp($rescon);

    if ($rescon =~ /success/) {
        return 1;
    } elsif ($rescon =~ /error.*code\s*:\s*'(.*)'/) {
        print "Error: $1". "\n";
        if ($retry < 2) {
            print "Trying to resend..\n";
            return send_bck($key, $secret, $filename, $usefname, $desc, ++$retry);
        }
    }
    return 0;
}

1;
